% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllGenerics.R, R/AllHelperFunctions.R
\name{slingPseudotime}
\alias{slingPseudotime}
\alias{slingCurveWeights}
\alias{slingPseudotime,SlingshotDataSet-method}
\alias{slingPseudotime,SingleCellExperiment-method}
\alias{slingCurveWeights,SlingshotDataSet-method}
\alias{slingCurveWeights,SingleCellExperiment-method}
\title{Get Slingshot pseudotime values}
\usage{
slingPseudotime(x, ...)

slingCurveWeights(x, ...)

\S4method{slingPseudotime}{SlingshotDataSet}(x, na = TRUE)

\S4method{slingPseudotime}{SingleCellExperiment}(x, na = TRUE)

\S4method{slingCurveWeights}{SlingshotDataSet}(x, as.probs = FALSE)

\S4method{slingCurveWeights}{SingleCellExperiment}(x)
}
\arguments{
\item{x}{an object containing \code{\link{slingshot}} output.}

\item{...}{additional parameters to be passed to object-specific methods.}

\item{na}{logical. If \code{TRUE} (default), cells that are not assigned to a
lineage will have a pseudotime value of \code{NA}. Otherwise, their
arclength along each curve will be returned.}

\item{as.probs}{logical. If \code{FALSE} (default), output will be the
weights used to construct the curves, appropriate for downstream analysis
of individual lineages (ie. a cell shared between two lineages can have two
weights of \code{1}). If \code{TRUE}, output will be scaled to represent
probabilistic assignment of cells to lineages (ie. a cell shared between
two lineages will have two weights that sum to \code{1}).}
}
\value{
an \code{n} by \code{L} matrix representing each cell's pseudotime
  along each lineage.

an \code{n} by \code{L} matrix of cell weights along
  each lineage.
}
\description{
Extract the matrix of pseudotime values or cells' weights along
  each lineage.
}
\section{Methods (by class)}{
\itemize{
\item \code{SlingshotDataSet}: returns the matrix of pseudotime values from a
\code{\link{SlingshotDataSet}} object.

\item \code{SingleCellExperiment}: returns the matrix of pseudotime values from a
\code{\link{SingleCellExperiment}} object.

\item \code{SlingshotDataSet}: returns the matrix of cell weights along each
lineage from a \code{\link{SlingshotDataSet}} object.

\item \code{SingleCellExperiment}: returns the matrix of cell weights along each
lineage from a \code{\link{SingleCellExperiment}} object.
}}

\examples{
data("slingshotExample")
rd <- slingshotExample$rd
cl <- slingshotExample$cl
sds <- slingshot(rd, cl)
slingPseudotime(sds)
data("slingshotExample")
rd <- slingshotExample$rd
cl <- slingshotExample$cl
sds <- slingshot(rd, cl)
slingCurveWeights(sds)
}
